GitTools

Struct GitTools 

pub struct GitTools { /* private fields */ }
Git operations service

Implementations

Source

impl GitTools

pub fn new(work_dir: Option<PathBuf>) -> GitTools

pub fn with_work_dir(self, dir: PathBuf) -> GitTools

Set working directory

pub fn rev_parse_toplevel(&self) -> Result<PathBuf, AppError>

Resolve the repository top-level path.

pub fn current_branch(&self) -> Result<String, AppError>

Return the current branch name.

pub fn branch_exists(&self, branch: &str) -> Result<bool, AppError>

Check whether a local branch exists.

pub fn path_is_git_repo(&self) -> Result<bool, AppError>

Check whether the current working directory is inside a git repository.

pub fn worktree_list(&self) -> Result<Vec<GitWorktreeInfo>, AppError>

List all worktrees for the repository.

pub fn worktree_add( &self, path: &Path, branch: &str, base_branch: &str, create_branch: bool, ) -> Result<GitWorktreeInfo, AppError>

Create a worktree for an existing or new branch.

pub fn worktree_remove(&self, path: &Path, force: bool) -> Result<(), AppError>

Remove a worktree path.

pub fn worktree_prune(&self) -> Result<(), AppError>

Prune stale worktree metadata.

pub fn is_worktree_clean(&self, path: &Path) -> Result<bool, AppError>

Check whether a worktree has uncommitted changes.

pub fn status(&self) -> Result<GitStatus, AppError>

Get repository status

pub fn diff( &self, staged: bool, path: Option<&Path>, ) -> Result<String, AppError>

Get diff (staged or unstaged)

pub fn log( &self, limit: Option<usize>, path: Option<&Path>, ) -> Result<Vec<CommitInfo>, AppError>

Get commit log

pub fn commit(&self, message: &str, all: bool) -> Result<CommitInfo, AppError>

Create a commit

pub fn undo(&self, soft: bool) -> Result<String, AppError>

Undo last commit (soft reset)

pub fn branches(&self, all: bool) -> Result<Vec<BranchInfo>, AppError>

List branches

pub fn checkout(&self, target: &str, create: bool) -> Result<String, AppError>

Checkout branch or file

pub fn stash( &self, pop: bool, message: Option<&str>, ) -> Result<String, AppError>

Stash changes

pub fn blame( &self, path: &Path, line_range: Option<(usize, usize)>, ) -> Result<String, AppError>

Get blame for file